package volgo

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Non_raising.SSource

The interface exported by Vcs.

'a result is the identity for the raising API, or a type based on Result depending on the API selected by the user in the non-raising APIs.

The individual functions are documented in the Vcs module.

type 'a t constraint 'a = < .. >
type 'a result
val init : < Volgo__.Trait.init.. > t -> path:Fpath_sexp0.Absolute_path.t -> Volgo__.Repo_root.t result
val find_enclosing_git_repo_root : < Volgo__.Trait.file_system.. > t -> from:Fpath_sexp0.Absolute_path.t -> Volgo__.Repo_root.t option result
val find_enclosing_repo_root : < Volgo__.Trait.file_system.. > t -> from:Fpath_sexp0.Absolute_path.t -> store:(Fpath_sexp0.Fsegment.t * 'store) list -> ('store * Volgo__.Repo_root.t) option result
val add : < Volgo__.Trait.add.. > t -> repo_root:Volgo__.Repo_root.t -> path:Path_in_repo.t -> unit result
val commit : < Volgo__.Trait.commit ; Volgo__.Trait.current_revision.. > t -> repo_root:Volgo__.Repo_root.t -> commit_message:Volgo__.Commit_message.t -> Rev.t result
val current_branch : < Volgo__.Trait.current_branch.. > t -> repo_root:Volgo__.Repo_root.t -> Branch_name.t result
val current_revision : < Volgo__.Trait.current_revision.. > t -> repo_root:Volgo__.Repo_root.t -> Rev.t result
val ls_files : < Volgo__.Trait.ls_files.. > t -> repo_root:Volgo__.Repo_root.t -> below:Path_in_repo.t -> Path_in_repo.t list result
val show_file_at_rev : < Volgo__.Trait.show.. > t -> repo_root:Volgo__.Repo_root.t -> rev:Rev.t -> path:Path_in_repo.t -> [ `Present of string | `Absent ] result
val load_file : < Volgo__.Trait.file_system.. > t -> path:Fpath_sexp0.Absolute_path.t -> string result
val save_file : ?perms:int -> < Volgo__.Trait.file_system.. > t -> path:Fpath_sexp0.Absolute_path.t -> file_contents:string -> unit result
val read_dir : < Volgo__.Trait.file_system.. > t -> dir:Fpath_sexp0.Absolute_path.t -> Fpath_sexp0.Fsegment.t list result
val rename_current_branch : < Volgo__.Trait.branch.. > t -> repo_root:Volgo__.Repo_root.t -> to_:Branch_name.t -> unit result
val name_status : < Volgo__.Trait.name_status.. > t -> repo_root:Volgo__.Repo_root.t -> changed:Volgo__.Name_status.Changed.t -> Volgo__.Name_status.Change.t list result
val num_status : < Volgo__.Trait.num_status.. > t -> repo_root:Volgo__.Repo_root.t -> changed:Volgo__.Name_status.Changed.t -> Volgo__.Num_status.Change.t list result
val log : < Volgo__.Trait.log.. > t -> repo_root:Volgo__.Repo_root.t -> Log.Line.t list result
val refs : < Volgo__.Trait.refs.. > t -> repo_root:Volgo__.Repo_root.t -> Refs.Line.t list result
val graph : < Volgo__.Trait.log ; Volgo__.Trait.refs.. > t -> repo_root:Volgo__.Repo_root.t -> Volgo__.Graph.t result
val set_user_name : < Volgo__.Trait.config.. > t -> repo_root:Volgo__.Repo_root.t -> user_name:Volgo__.User_name.t -> unit result
val set_user_email : < Volgo__.Trait.config.. > t -> repo_root:Volgo__.Repo_root.t -> user_email:Volgo__.User_email.t -> unit result
val git : ?env:string array -> ?run_in_subdir:Path_in_repo.t -> < Volgo__.Trait.git.. > t -> repo_root:Volgo__.Repo_root.t -> args:string list -> f:(Volgo__.Git.Output.t -> 'a result) -> 'a result

See the note in Vcs.git about error handling with respect to exceptions raised by f.

Some helpers dedicated to the corresponding result type are provided by the module Vcs.Git. They are convenient to use to build the f parameter.

val hg : ?env:string array -> ?run_in_subdir:Path_in_repo.t -> < Volgo__.Trait.hg.. > t -> repo_root:Volgo__.Repo_root.t -> args:string list -> f:(Volgo__.Hg.Output.t -> 'a result) -> 'a result