package volgo

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Change.Num_statSource

Sourcetype t =
  1. | Num_lines_in_diff of Num_lines_in_diff.t
  2. | Binary_file

The number of lines in diff is not always given by git - indeed sometimes the line of output for this file contains dash '-' characters in lieu of the number of insertions or deletions. According to man git diff this happens for binary files.

Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourceval equal : t -> t -> bool