package volgo

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Vcs.Platform_repoSource

A type to uniquely identify a repository hosted on a platform.

Sourcemodule Vcs_kind : sig ... end

Some platform support hosting Mercurial repositories. We use this type to distinguish.

Sourcetype t = {
  1. platform : Platform.t;
  2. vcs_kind : Vcs_kind.t;
  3. user_handle : User_handle.t;
  4. repo_name : Repo_name.t;
}
Sourceval compare : t -> t -> int
Sourceval equal : t -> t -> bool
Sourceval hash : t -> int
Sourceval seeded_hash : int -> t -> int
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourcemodule Protocol : sig ... end
Sourcemodule Ssh_syntax : sig ... end

There are two style of SSH addresses used by popular platforms.

Sourcemodule Url : sig ... end

A Url for a platform repo that is suitable to perform vcs operations, such as clone.

Sourceval to_url : t -> protocol:Protocol.t -> Url.t
Sourceval of_url : Url.t -> t