package volgo

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Private.Bit_vectorSource

A naive implementation of mutable bit vectors.

At some point, with some benchmarks for sanity checks, it seems desirable to switch to a less naive implementation.

Sourcetype t
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourceval create : len:int -> bool -> t
Sourceval length : t -> int
Sourceval set : t -> int -> bool -> unit
Sourceval get : t -> int -> bool
Sourceval reset : t -> bool -> unit
Sourceval copy : t -> t

In place bitwise operations

Sourceval bw_and_in_place : mutates:t -> t -> unit