package volgo

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Private.Process_outputSource

Manipulating the output of process run by vcs and backends.

This module is used to break a dependency cycle. It serves under the hood for the implemenation of the types that are exported as Vcs.Git.Output and Vcs.Hg.Output, although for added type safety, these 2 types are not exported as being equal.

Sourcetype t = {
  1. exit_code : int;
  2. stdout : string;
  3. stderr : string;
}
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourcemodule Private : sig ... end

Exported for use by Git and Hg outputs.