package volgo

  1. Overview
  2. Docs
On This Page
  1. Accessors
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Vcs.RefsSource

Capturing the information related to git refs.

In this file we represent the output of the git show-ref command. In particular we represent the location of all known local branches heads, remote branches heads and tags.

It is worth noting that the location of the remote branches is the state of the remote branches as they are currently known locally.

Sourcemodule Line : sig ... end
Sourcetype t = Line.t list
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourceval equal : t -> t -> bool

Accessors

Sourceval tags : t -> Tag_name.t list
Sourceval local_branches : t -> Branch_name.t list
Sourceval remote_branches : t -> Remote_branch_name.t list